@@ -2,34 +2,31 @@ from CFNetwork import *
 from PyObjCTools.TestSupport import *
 import sys
 
-try:
-    long
-except NameError:
-    long = int
-
-try:
-    unicode
-except NameError:
-    unicode = str
-
 if sys.version_info[0] != 2:
     def buffer(value):
         return value.encode('latin1')
 
 class TestCFHTTPMessage (TestCase):
-    @min_os_level('10.6')
-    def testConstants10_6(self):
+    @min_os_level('10.9')
+    @expectedFailure
+    def testConstants10_9(self):
+        self.assertIsInstance(kCFHTTPAuthenticationSchemeOAuth1, unicode)
+
+    @min_os_level('10.7')
+    def testConstants10_7(self):
         self.assertIsInstance(kCFHTTPAuthenticationSchemeNegotiate2, unicode)
         self.assertIsInstance(kCFHTTPAuthenticationSchemeXMobileMeAuthToken, unicode)
 
+
     @min_os_level('10.5')
     def testConstants10_5(self):
         self.assertIsInstance(kCFHTTPAuthenticationSchemeNTLM, unicode)
         self.assertIsInstance(kCFHTTPAuthenticationSchemeNegotiate, unicode)
 
     @expectedFailure
-    @min_os_level('10.5')
-    def testConstants10_5_failure(self):
+    @min_os_level('10.10')
+    def testConstants10_10(self):
+        self.assertIsInstance(kCFHTTPVersion2_0, unicode)
         self.assertIsInstance(kCFHTTPAuthenticationSchemeKerberos, unicode)
 
     def testConstants(self):
